==> haskell-xcb-types-0.8.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xcb-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcb-types
version: 0.8.0
id: xcb-types-0.8.0-IyGvWCOdZzd7cgO0lPNcDI
key: xcb-types-0.8.0-IyGvWCOdZzd7cgO0lPNcDI
license: BSD3
maintainer: Antoine Latter <aslatter@gmail.com>
homepage: http://community.haskell.org/~aslatter/code/xcb-types
synopsis: Parses XML files used by the XCB project
description:
    This package provides types which mirror the structures
    used in the XCB code generation XML files.
    .
    See project http://xcb.freedesktop.org/ for more information about the XCB
    project.
    .
    The XML files describe the data-types, events and requests used by the
    X Protocol, and are used to auto-generate large parts of the XCB project.
    .
    This package parses these XML files into Haskell data structures.
    .
    If you want to do something with these XML descriptions but don'\''t want
    to learn XSLT, this package should help.
    .
    This version of xcb-types is intended to fully parse the X Protocol
    description version 1.4.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.XCB Data.XCB.Types Data.XCB.Pretty Data.XCB.FromXML
hidden-modules: Data.XCB.Utils
abi: a920f4a2d9c2ff880b6941d4dca18fae
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/xcb-types-0.8.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/xcb-types-0.8.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/xcb-types-0.8.0
hs-libraries: HSxcb-types-0.8.0-IyGvWCOdZzd7cgO0lPNcDI
depends:
    base-4.9.0.0 containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pretty-1.1.3.3 xml-1.3.14-rYbwgRBahsKh5Xn1LyTeP
haddock-interfaces: /usr/share/doc/haskell-xcb-types/html/xcb-types.haddock
haddock-html: /usr/share/doc/haskell-xcb-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcb-types-0.8.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xcb-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcb-types
version: 0.8.0
id: xcb-types-0.8.0-Ly5OoWOGNp4G6VvpEdVeST
key: xcb-types-0.8.0-Ly5OoWOGNp4G6VvpEdVeST
license: BSD3
maintainer: Antoine Latter <aslatter@gmail.com>
homepage: http://community.haskell.org/~aslatter/code/xcb-types
synopsis: Parses XML files used by the XCB project
description:
    This package provides types which mirror the structures
    used in the XCB code generation XML files.
    .
    See project http://xcb.freedesktop.org/ for more information about the XCB
    project.
    .
    The XML files describe the data-types, events and requests used by the
    X Protocol, and are used to auto-generate large parts of the XCB project.
    .
    This package parses these XML files into Haskell data structures.
    .
    If you want to do something with these XML descriptions but don'\''t want
    to learn XSLT, this package should help.
    .
    This version of xcb-types is intended to fully parse the X Protocol
    description version 1.4.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.XCB Data.XCB.Types Data.XCB.Pretty Data.XCB.FromXML
hidden-modules: Data.XCB.Utils
abi: 29c3fc97830f90a7d9ac05e9328eb58d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/xcb-types-0.8.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/xcb-types-0.8.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/xcb-types-0.8.0
hs-libraries: HSxcb-types-0.8.0-Ly5OoWOGNp4G6VvpEdVeST
depends:
    base-4.9.0.0 containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pretty-1.1.3.3 xml-1.3.14-9IpHbL0QRqR5eAZpdkwTMQ
haddock-interfaces: /usr/share/doc/haskell-xcb-types/html/xcb-types.haddock
haddock-html: /usr/share/doc/haskell-xcb-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
